%% AS
%
% This calculates the HAM6 AS port Wave front sensors.  

lambda = 1.064e-6;
mm = 1e-3;
f1 = 343e-3;   % CVI lens
f1 = 333e-3;   % r = 150mm fused silica lens

% Coordinates and optics
OpticalLayout;                    % load the layout from the model

idSRM = strmatch('SRM', OpticNames);
R_SRM = layout(idSRM).ROC;         % optic (and beam) radius of curvature)
w_SRM = layout(idSRM).waist;       % laser beam radius
tSRM =  layout(idSRM).thickness;   % optic thickness
nSRM = 1.45;                      % index of refraction

% distances
dSRM_TT1 = 3.646;                   % from T1000317
dTT1_TT2 = 1.395;
dTT2_TT3 = 0.708;
dTT3_L1  = 0.5;

R_TT1 = 4.6;
R_TT2 = 1.7;


% build beam path to PR2 (remember, POP comes from BS, not SRM)
as = beamPath;
as.seedq = beamq.beamWaistAndR(w_SRM, R_SRM);         % input waist
as.seedz = 0;
as.addComponent(component.dielectric(-R_SRM, inf, tSRM, nSRM, 1e-6, 'SRM'));
as.addComponent(component.curvedMirror(R_TT1, dSRM_TT1-tSRM, 'TT1'));
as.addComponent(component.curvedMirror(R_TT2, as.component('TT1').z+dTT1_TT2, 'TT2'));
as.addComponent(component.flatMirror(as.component('TT2').z+dTT2_TT3, 'TT3'));

as.addComponent(component.lens(f1, as.component('TT3').z+0.5, 'L1'));
%as.addComponent(component.lens(0.343, as.component('L1').z+0.3, 'L2'));

as.targetWaist(250e-6, 7);
as = as.optimizePath('L1', as.component('L1').z + [-0.6 0.6], ...
                    'target', as.component('L1').z + [0.1 2]);
qOut = as.qPropagate(as.component('L1').z + 1e-6);
waistZ = as.component('L1').z - qOut.waistZ;
as.addComponent(component.flatMirror(waistZ - qOut.rayleighRange, 'QPD1'));
as.addComponent(component.flatMirror(waistZ + qOut.rayleighRange, 'QPD2'));



% plot beam
clf
zz = 3:0.01:8;
as.plotSummary(zz);
saveas(gcf, 'AS_beampath.pdf', 'pdf');
shg;