%% PRM
% 
% This calculates the beam propagation into HAM1 from the PRM refl beam.
%
lambda = 1.064e-6;
mm = 1e-3;

% Coordinates and optics
OpticalLayout;       % load the optics from the file.

nPRM = strmatch('PRM', OpticNames);       % Get indices
nSM2 = strmatch('SM2', OpticNames);
nSM1 = strmatch('SM1', OpticNames);
nPMMT2 = strmatch('PMMT2', OpticNames);
nPMMT1 = strmatch('PMMT1', OpticNames);

R_prm = layout(nPRM).ROC;             % optic (and beam) radius of curvature)
w_prm = layout(nPRM).waist;           % laser beam radius
tPRM =  layout(nPRM).thickness;       % optic thickness
idxPRM = 1.45;                        % index of refraction


% distances
dPRM_SM2     = norm(layout(nPRM).position - layout(nSM2).position);
dSM2_PMMT2   = norm(layout(nSM2).position - layout(nPMMT2).position);                               
dPMMT2_PMMT1 = norm(layout(nPMMT2).position - layout(nPMMT1).position);    
dHam1 = 2500 * mm;                        % estimate from chamber locations


% build beam path to HAM1
refl = beamPath;
refl.seedq = beamq.beamWaistAndR(w_prm, R_prm);                           % input waist
refl.seedz = 0;

refl.addComponent(component.dielectric(-R_prm, inf, tPRM, idxPRM, 1e-6, 'PRM'));
refl.addComponent(...
    component.flatMirror(dPRM_SM2 - tPRM, 'SM2')); % SM2 minus PRM thickness
refl.addComponent(...
    component.curvedMirror(layout(nPMMT2).ROC, dPRM_SM2 + dSM2_PMMT2 - tPRM, 'PMMT2'));
refl.addComponent(...
    component.curvedMirror(layout(nPMMT1).ROC, dPMMT2_PMMT1 + dPRM_SM2 + dSM2_PMMT2 - tPRM, 'PMMT1'));
refl.addComponent(...
    component.flatMirror(dHam1 + dPMMT2_PMMT1 + dPRM_SM2 + dSM2_PMMT2 - tPRM, 'HAM1'));

    
% plot beam
clf
zz = -4:0.01:12;
refl.plotSummary(zz);

qHAM1 = refl.qPropagate(refl.component('HAM1').z)
